checkRequire("Lua_ItemOutputItem");
Lua_ItemOutputWindow = class("Lua_ItemOutputWindow", Lua_Window);
function Lua_ItemOutputWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ItemOutputWindow";
	self.skinName = "ItemOutputWindow_skin";
	self.isClickClose = true;
end

function Lua_ItemOutputWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.itemImg = Lua_ToolImage.new(self.content);
	self.itemImg:setDepth(5);
	self.itemImg:setLocation(-135.5, 100, 0);

	self.dragContainer = Lua_DragContainer.new(self.content, 1, Vector4(0, 0, 450, 90));

	self.desList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 450, 90));
	self.desList:setListCell(Lua_OutputListItem, 40, 450, 1);
	self.desList:setLocation(0, -8, 0);

	self.subBtn:addClickFuntion(self, self.hide);
end

function Lua_ItemOutputWindow:showWin(param)
	local itemData = param[1];
	self.itemImg.data = itemData;
	self.itemTxt.text = itemData.colorName;

	local arr;
	if itemData.outputDes == nil then
		arr = Array();
	else
		arr = string.split(itemData.outputDes, "\n");
	end

	if itemData.subType ~= Lua_PackTypeDefine.MOUNT_EQUIP_TYPE then
		self.dragContainer:setEnable(true);
		self.desList:setEnable(false);

		local item = Lua_OutputItem.new(self.dragContainer.content);
		item:setShowHeight(arr:getSize() > 3 and 90 or 45);
		item:setShowData(itemData, arr);
		self.dragContainer.childrenList:clear();
		self.dragContainer:addSubContainer(item, true);
		self.dragContainer.canDrag = arr:getSize() > 6;

		if arr:getSize() > 3 then
			self.itemImg:setLocation(-135.5, 100, 0);
			self.itemTxt:setLocation(-80, 100, 0);

			self.dragContainer:updateClipRegion(Vector4(0, 0, 450, 90));
			self.dragContainer:setLocation(0, -8, 0);
		else
			self.itemImg:setLocation(-135.5, 80, 0);
			self.itemTxt:setLocation(-80, 80, 0);

			self.dragContainer:updateClipRegion(Vector4(0, 0, 450, 45));
			self.dragContainer:setLocation(0, -20.5, 0);
		end
	else -- 骑装特殊情况
		self.dragContainer:setEnable(false);
		self.desList:setEnable(true);

		local desArr = Array();
		for i = 1, arr:getSize() do
			desArr:add({tvo = itemData, desStr = arr[i]});
		end
		self.desList:setLuaArrayData(desArr, false);
	end
end

function Lua_ItemOutputWindow:dispose()
	if self.itemImg ~= nil then
		self.itemImg:dispose();
		self.itemImg = nil;
	end
	if self.dragContainer ~= nil then
		self.dragContainer:dispose();
		self.dragContainer = nil;
	end

	self:superCall("dispose");
end





--------------------------------------------------





Lua_OutputItem = class("Lua_OutputItem", Lua_DragContainerItem);
function Lua_OutputItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_OutputItem:setShowHeight(showHeight)
	self.showHeight = showHeight;
end

function Lua_OutputItem:setShowData(tvo, desArr)
	self.data = tvo;
	self.desLen = desArr:getSize();

	local desLab;
	for i = 1, desArr:getSize() do
		desLab = UICreate.createLabel(self.content, "", 0, 0, 100, 30, 24);
		desLab.pivot = UIWidget.Pivot.TopLeft;
		desLab.colorStr = Lua_ColorDefine.transColor("00E125", 1);
		desLab.overflowMethod = UILabel.Overflow.ResizeFreely;
		desLab.clickScale = false;
		desLab.text = desArr[i];
		desLab:setDepth(3);
		desLab:addUrlClickFuntion(self, self.onDescTxtUrlClick);
		desLab:setLocation(-200 + 150 * ((i + 2) % 3), self.showHeight / 2 - (math.ceil((i / 3) - 1)) * 50, 0);
	end
end

function Lua_OutputItem:onDescTxtUrlClick(url)
	local list = self.data:getOutputDesInfo(url);
	if list ~= nil and Lua_PackUtil.checkOpenWinFunOpen(list) == true then
		Lua_WindowUtil.openWin("Lua_ItemOutputWindow", WinParam.ACTION_CLOSE);
		Lua_WindowUtil.openWin("Lua_ForgingWindow", WinParam.ACTION_CLOSE);

		local itemID;
		if list[1].winName == "Lua_ShopWindow" and list[1].itemID ~= nil then
			if type(list[1].itemID) == "table" then
				itemID = list[1].itemID[DataCenter.roleData.career];
			elseif type(list[1].itemID) == "number" then
				itemID = list[1].itemID;
			end
		end
		Lua_PackUtil.openWinByList(list, nil, nil, false, itemID);
	end
end

function Lua_OutputItem:getHeight()
	local height;
	if self.desLen > 0 then
		height = (math.ceil(self.desLen / 3) - 1) * 50 + 24;
	else
		height = 0;
	end
	return height;
end





--------------------------------------------------





Lua_OutputListItem = class("Lua_OutputListItem", Lua_ListCell);
function Lua_OutputListItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_OutputListItem:buildShowItem()
	self:superCall("buildShowItem");

	self.desLab = UICreate.createLabel(self.content, "", -225, 20, 450, 30, 24);
	self.desLab.pivot = UIWidget.Pivot.TopLeft;
	self.desLab.colorStr = Lua_ColorDefine.transColor("00E125", 1);
	self.desLab.overflowMethod = UILabel.Overflow.ResizeFreely;
	self.desLab:setDepth(3);
end

function Lua_OutputListItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	self.desLab.text = data.desStr;
end

function Lua_OutputListItem:onPlayerSoundClick()
	local arr = string.split(self._data.desStr, "=");
	local url = string.split(arr[2], "]")[1];
	local list = self._data.tvo:getOutputDesInfo(url);
	if list ~= nil and Lua_PackUtil.checkOpenWinFunOpen(list) == true then
		Lua_WindowUtil.openWin("Lua_ItemOutputWindow", WinParam.ACTION_CLOSE);
		Lua_WindowUtil.openWin("Lua_ForgingWindow", WinParam.ACTION_CLOSE);

		local itemID;
		if list[1].winName == "Lua_ShopWindow" and list[1].itemID ~= nil then
			if type(list[1].itemID) == "table" then
				itemID = list[1].itemID[DataCenter.roleData.career];
			elseif type(list[1].itemID) == "number" then
				itemID = list[1].itemID;
			end
		end
		Lua_PackUtil.openWinByList(list, nil, nil, false, itemID);
	end
end

function Lua_OutputListItem:dispose()
	if self.desLab ~= nil then
		self.desLab:dispose();
		self.desLab = nil;
	end
	self._data = nil;

	self:superCall("dispose");
end