Lua_PackCellsItem = class("Lua_PackCellsItem", Lua_ListCell);
function Lua_PackCellsItem:buildShowItem()
	self:superCall("buildShowItem");

	self.lastClickIndex = -1;
	self.lastClickTime = 0;
	self.cellSize = 25;

	local toolImg;
	local px;
	local py;
	local perWidth = 90;
	local perHeight = 90;
	self.cellPosX = {{-220, -140}, {-130, -50}, {-40, 40}, {50, 130}, {140, 220}};
	self.cellPosY = {{140, 220}, {50, 130}, {-40, 40}, {-130, -50}, {-220, -140}};
	self.cells = Array();
	for i = 1, self.cellSize do
		px = (i - 1) % 5;
		py = math.ceil(i / 5);

		toolImg = Lua_ToolImage.new(self.content);
		toolImg.defaultRoundEffect = true;
		toolImg:setLocation(-perWidth * 5 / 2 + px * perWidth + perWidth / 2, perHeight / 2 + perHeight * 5 / 2  - perHeight * py, 0);
		toolImg:setDepth(3);
		toolImg:setCanClick(false);
		toolImg.content.name = "c"..i;
		self.cells:add(toolImg);
	end
	self:addLuaEvent("UPDATE_SALE_ITEM", self, self.onUpdateSaleItem);
	self:addLuaEvent("UPDATE_NEW_TAG", self, self.onUpdateNewTag);
end

function Lua_PackCellsItem:setData(data)
	self.startIndex = data.startIndex;

	local bagData = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK);
	local packSize = bagData.packSize;
	for i = 1, self.cellSize do
		self.cells[i].curIndex = self.cells[i];

		local curIndex = data.startIndex + i - 1;
		local td = bagData:getItemByIndex(curIndex);
		if curIndex >= packSize and td == nil then -- 没开锁
			self.cells[i].data = nil;
			self.cells[i]:showLockSlot(true);
			self.cells[i]:clearCdListener();
		else
			self.cells[i]:showLockSlot(false);
			self.cells[i].data = td;
			if td ~= nil then
				self.cells[i]:addCdListener();
				self.cells[i]:onCheckItemCd();
			end
		end
	end
	self:onUpdateSaleItem(nil);
end

function Lua_PackCellsItem:onUpdateSaleItem(val)
	local bagData = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK);
	if DataCenter.packData.showSalePanel == true then
		for i = 1, self.cellSize do
			if self.cells[i].data ~= nil and self.cells[i].data.sysPrice == 0 then
				self.cells[i]:setGray(true);
			else
				if self.cells[i].data ~= nil and bagData.saleDic[self.cells[i].data.index] ~= nil then
					self.cells[i]:showSelected(true);
					self.cells[i]:setGray(true);
				else
					self.cells[i]:showSelected(false);
					self.cells[i]:setGray(false);
				end
			end
		end
	else
		for i = 1, self.cellSize do
			self.cells[i]:showSelected(false);
			self.cells[i]:setGray(false);
		end
	end
end

function Lua_PackCellsItem:onUpdateNewTag(val)
	local left = val - self.startIndex + 1;
	if left > 0 and left <= self.cellSize and self.cells[left] ~= nil then
		if self.cells[left].data ~= nil then
			self.cells[left].data = self.cells[left].data;
		end
	end
end

function Lua_PackCellsItem:checkOutBound(showRect)
	local rect;
	local width = self.cells[1].item_bg.width;
	local height = self.cells[1].item_bg.height;
	for i = 1, self.cellSize do
		if self.cells[i].data ~= nil then
			rect = Lua_Rectangle.new(self.itemX + self.cells[i].x - width / 2, self.itemY + self.cells[i].y - height / 2, width, height);
			self.cells[i]:showRoundEffectView(showRect:containeRect(rect));
		end
	end
end

function Lua_PackCellsItem:onPlayerSoundClick()
	local v = Vector3(UnityEngine.Input.mousePosition.x,UnityEngine.Input.mousePosition.y,0);
	local screenpos = UICamera.mainCamera:ScreenToWorldPoint(v);
	local mousePosition = self.content.transform:InverseTransformPoint(screenpos);
	local cx = 0;
	for i,v in ipairs(self.cellPosX) do
		if v[1] <= mousePosition.x and v[2] > mousePosition.x then
			cx = i;
			break;
		end
	end
	if cx == 0 then
		return;
	end

	local cy = 0;
	for i,v in ipairs(self.cellPosY) do
		if v[1] <= mousePosition.y and v[2] > mousePosition.y then
			cy = i;
			break;
		end
	end
	if cy == 0 then
		return;
	end

	self.clickIndex = cx + (cy - 1) * 5;
	if DataCenter.packData.showWharePanel == false then
		self:onSingleClick();
	else
		if self.lastClickIndex ~= self.clickIndex or getTime() - self.lastClickTime > 0.3 then
			self.lastClickTime = getTime();
			self.lastClickIndex = self.clickIndex;
			Lua_CommonUtil.delayCall(0.3, self, self.onSingleClick);
		else
			Lua_CommonUtil.removeTimer(self, self.onSingleClick);
			self:onDoubleClick();
			self.lastClickTime = -1;
		end
	end
end

function Lua_PackCellsItem:onSingleClick()
	local totalIndex = self.clickIndex + (self.cellSeqIndex - 1) * 25;
	local bagData = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK);
	local packSize = bagData.packSize;
	if totalIndex > packSize then
		local unlockNum = totalIndex - packSize;
		Lua_WindowUtil.openWin("Lua_PackUnlockWindow", WinParam.ACTION_OPEN, unlockNum);
	else
		if self.cells[self.clickIndex] ~= nil and self.cells[self.clickIndex].data ~= nil then
			Lua_PackUtil:delNewTip(self.cells[self.clickIndex].data);
			if DataCenter.packData.showSalePanel == false then
				Lua_PackUtil.showItemInfo(self.cells[self.clickIndex].data);
			else
				local tvo = self.cells[self.clickIndex].data;
				if tvo.sysPrice == 0 then
					OperateAlert.show(LanUtil.getValue(110861));
					return;
				end

				local saleDic = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK).saleDic;
				local cindex = saleDic[tvo.index];
				if tvo.rare == false or cindex ~= nil then
					self:moveToSale(tvo);
				else
					Lua_WindowUtil.openWin("Lua_TipsWindow", nil, {owner = self, des = LanUtil.getValue(110892),
					data = tvo, type = 1, subFun = self.onSaleConfig});
				end
			end
		end
	end
end

function Lua_PackCellsItem:onSaleConfig(data)
	self:moveToSale(data.data);
end

function Lua_PackCellsItem:moveToSale(tvo)
	local saleDic = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK).saleDic;
	local cindex = saleDic[tvo.index];
	if cindex == nil then
		if table.length(saleDic) >= 30 then
			OperateAlert.show(LanUtil.getValue(110858));
			return;
		end

		if tvo.count == 1 then
			saleDic[tvo.index] = 1;
			Lua_MsgUtil.callFunc("UPDATE_SALE_ITEM");
		else
			Lua_WindowUtil.openWin("Lua_NumberInputWindow", WinParam.ACTION_OPEN,
				{owner = self, callBack = self.onSellNumSelect, callBackData = tvo,
				titleName = LanUtil.getValue(110890), maxNum = tvo.count, startMax = true});
		end
	else
		saleDic[tvo.index] = nil;
		Lua_MsgUtil.callFunc("UPDATE_SALE_ITEM");
	end
end

function Lua_PackCellsItem:onSellNumSelect(val, data)
	local saleDic = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK).saleDic;
	saleDic[data.index] = val;
	Lua_MsgUtil.callFunc("UPDATE_SALE_ITEM");
end

function Lua_PackCellsItem:onDoubleClick()
	local bagData = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK);
	local tvo = self.cells[self.clickIndex].data;
	if tvo == nil then
		return;
	end

	Lua_PackUtil:delNewTip(tvo);
	if tvo.type == 1 then
		if DataCenter.packData.showWharePanel == false then
			Lua_PackUtil.equItem(tvo);
		else
			Lua_PackUtil.toWhare(tvo);
		end
	elseif tvo.type ~= 1 then
		if DataCenter.packData.showWharePanel == false then
			Lua_PackUtil.useItem(tvo);
		else
			Lua_PackUtil.toWhare(tvo);
		end
	end
end

function Lua_PackCellsItem:dispose()
	Lua_CommonUtil.removeTimer(self, self.onSingleClick);
	
	self:superCall("dispose");
end