﻿checkRequire("Lua_MingSuoItem");
Lua_MingSuoFloorItem = class("Lua_MingSuoFloorItem", Lua_DisplayObject);
function Lua_MingSuoFloorItem:ctor(p)
    self:superCall("ctor", p);

    self.list = Array();
    self.showModels = Array();
    self.itemWidth = 55;
    self.itemHeight = 55;
    self._floorWidth = 0;
    self._floorHeight = 0;
end

function Lua_MingSuoFloorItem:buildShowItem()
    self:superCall("buildShowItem");

    self:addLuaEvent("MING_SUO_DROP", self, self.onMingSuoDrop);
    self:addLuaEvent("MING_SUO_MOVING", self, self.onMingSuoMoving);
end

function Lua_MingSuoFloorItem:setFloorData(fdata, isTips)
	self.floorData = fdata;
	local showList = fdata.floor_show;
	self:clear();
	self._floorWidth = 0;
	self._floorHeight = 0;

	local len = showList:getSize();
	for i = 1, len do
		local item = Lua_MingSuoItem.new(self.content);
		if isTips == true then
			item:setData(showList[i], false);
		else
			item:setData(showList[i], showList[i].canClick);
		end
		item:setLocation(showList[i].pos.x * self.itemWidth, -showList[i].pos.y * self.itemHeight, 0);
		
		if showList[i].pos.x > self._floorWidth then
			self._floorWidth = showList[i].pos.x;
		end
		
		if showList[i].pos.y > self._floorHeight then
			self._floorHeight = showList[i].pos.y;
		end
		self.list:add(item);
	end
end

function Lua_MingSuoFloorItem:onSetDepth(depth)
	local len = self.list:getSize()
	for i = 1, len do
		self.list[i]:onSetDepth(depth)
	end
end

function Lua_MingSuoFloorItem:onRemoveFun(value)
	local len = self.list:getSize()
	for i = 1, len do
		self.list[i]:onRemoveFun(value)
	end
end

function Lua_MingSuoFloorItem.Get:floorWidth()
	return (self._floorWidth + 1) * self.itemWidth;
end

function Lua_MingSuoFloorItem.Get:floorHeight()
	return (self._floorHeight + 1) * self.itemHeight;
end

function Lua_MingSuoFloorItem:onMingSuoDrop(info)
	local modelData = info.modelData;
	local mousePosition = self.content.transform:InverseTransformPoint(info.screenpos);
	local posX = math.floor(mousePosition.x / self.itemWidth + 0.5);
	local posY = math.floor(-mousePosition.y / self.itemHeight + 0.5);
	local offsetPosX = math.ceil(modelData.offset_pos[1] / self.itemWidth);
	local offsetPosY = math.floor(modelData.offset_pos[2] / self.itemHeight);
	Lua_ProxyManager.getProxy("Lua_MingSuoProxy"):sPutInfoMsg(modelData.modelIndex, modelData.floor, posX + offsetPosX, posY - offsetPosY);
end

function Lua_MingSuoFloorItem:onMingSuoMoving(data)
	for i = 1, self.list:getSize() do
		if tonumber(self.list[i].itemBg.mainContent.name) == data then
			self.list[i].itemBg:setAltas("packWindow", "ui_knapsack_icon_c");
		end
	end
end

function Lua_MingSuoFloorItem:showModel(modelId, posx, posy)
	self:removeModel(modelId);
	
	local modelData = self.floorData:getModelById(modelId);
	local model = Lua_MingSuoItemModel.new(self.content, false, modelData.modelIndex);
	model:setDepth(7);
	model:setData(modelData, true);
	model:setLocation(posx * self.itemWidth + self.itemWidth / 2, -1 * posy * self.itemHeight - self.itemHeight / 2);
	self.showModels:add(model);
end

function Lua_MingSuoFloorItem:removeModel(id)
	for i = 1, self.showModels:getSize() do
		if self.showModels[i].data.modelIndex == id then
			self.showModels[i]:dispose();
			self.showModels:remove(i);
			break;
		end
	end
end

function Lua_MingSuoFloorItem:clear()
	for i = 1, self.list:getSize() do
		self.list[i]:dispose();
	end
	self.list:clear();

	for i = 1, self.showModels:getSize() do
		self.showModels[i]:dispose();
	end
	self.showModels:clear();
end